<?php

namespace Drupal\mailgo\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class GlobalConfigForm.
 */
class GlobalConfigForm extends ConfigFormBase {

  /**
   * Drupal\Core\Config\ConfigManager definition.
   *
   * @var \Drupal\Core\Config\ConfigManager
   */
  protected $configManager;

  /**
   * @param ContainerInterface $container
   * @return GlobalConfigForm|ConfigFormBase|static
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'mailgo.globalconfig',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'mailgo_global_config_form';
  }

  /**
   * {@inheritdoc}
   */
  static public function getDefaultConfig() {
    return [
      'skin' => 'light',
//      'load_css' => TRUE,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('mailgo.globalconfig');

    $form['skin'] = [
      '#type' => 'select',
      '#title' => $this->t('Skin'),
      '#description' => $this->t('The styling which will be used for MailGo pop-up.'),
      '#default_value' => $config->get('mailgo.skin'),
      '#options' => [
        'light' => $this->t("Light"),
        'dark' => $this->t("Dark")
      ]
    ];

//    $form['load_css'] = [
//      '#type' => 'checkbox',
//      '#title' => $this->t('Load CSS Library'),
//      '#description' => $this->t('If checked, module will load CSS Styles From MailGo Library'),
//      '#default_value' => $config->get('mailgo.load_css'),
//    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    $config = $this->config('mailgo.globalconfig');
    $config->set('mailgo.skin', $form_state->getValue('skin'));
//    $config->set('mailgo.load_css', $form_state->getValue('load_css'));
    $config->save();
  }

}
