<?php

/**
 * @file
 * Contains \Drupal\mailgo\Plugin\Field\FieldFormatter\MailGoFormatter.
 */

namespace Drupal\mailgo\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'url_embed' formatter.
 *
 * @FieldFormatter(
 *   id = "mailgo",
 *   label = @Translation("MailGo Link"),
 *   field_types = {
 *     "email"
 *   }
 * )
 */
class MailGoFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return [
        'view_mode' => 'mailgo_email',
        'no_spam' => false
      ] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $options = [
      'mailgo_email' => 'MailGo E-Mail Link',
      'regular_mailto' => 'Regular mailto'
    ];

    return [
        'view_mode' => [
          '#type' => 'select',
          '#title' => t('View mode of the MailGo'),
          '#options' => $options,
          '#default_value' => $this->getSetting('view_mode'),
        ],
        'no_spam' => [
          '#type' => 'checkbox',
          '#title' => t('Hide E-mail from DOM'),
          '#default_value' => $this->getSetting('no_spam'),
        ]
      ];
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = [];
    $summary[] = t('MailGo view mode: @view_mode', ['@view_mode' => $this->getSetting('view_mode')]);
    $summary[] = t('Prevent spam: @no_spam', ['@no_spam' => $this->getSetting('no_spam') ? 'yes': 'no']);
    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
      /** @var \Drupal\mailgo\MailGoManager $service */
      $service = \Drupal::service('mailgo');
      $element = [];
      $viewMode = $this->getSetting('view_mode');
      $noSpam = $this->getSetting('no_spam');
      $config = $service->getConfig();
      $isDark = $config->get('mailgo.skin') === 'dark';
      $attachments = [
          'library' => $isDark ? 'mailgo/mailgo-dark' : 'mailgo/mailgo'
      ];
      foreach ($items as $delta => $item) {
          $text = $item->getValue();
          if (!empty($text['value'])) {
              $markup = null;
              switch ($viewMode) {
                case 'mailgo_email':
                  $markup = $service->processEmailsInText($text['value'], $noSpam);
                  break;
                case 'regular_mailto':
                  $markup = $service->generateRegularMailToLink($text['value']);
                  break;
                default:
                  $markup = $text['value'];
              }
              $element[$delta]['#attached'] = $attachments;
              $element[$delta]['#markup'] = $markup;
          }
      }
      return $element;
  }
}
