<?php

namespace Drupal\mailgo\Plugin\Filter;

use Drupal\Core\Form\FormStateInterface;
use Drupal\filter\FilterProcessResult;
use Drupal\filter\Plugin\FilterBase;
use Drupal\mailgo\MailGoManager;

/**
 * Provides a filter to convert emails to mailgo links.
 *
 * @Filter(
 *   id = "mailgo_filter",
 *   title = @Translation("MailGo filter"),
 *   description = @Translation("Converts emails/phones into links with MailGo popup window"),
 *   type = Drupal\filter\Plugin\FilterInterface::TYPE_MARKUP_LANGUAGE,
 * )
 */
class MailGoFilter extends FilterBase {

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    //emails processing
      $form['mailgo_process_emails'] = [
          '#type' => 'checkbox',
          '#title' => $this->t('Process E-Mails'),
          '#default_value' => !empty($this->settings['mailgo_process_emails']) ? 1 : 0,
          '#description' => $this->t('Emails will be performed as MailGo-links'),
      ];
    //no spam activate
      $form['mailgo_no_spam'] = [
          '#type' => 'checkbox',
          '#title' => $this->t('Enable anti-spam mode'),
          '#default_value' => !empty($this->settings['mailgo_no_spam']) ? 1 : 0,
          '#description' => $this->t('Hide email from DOM ("data" attributes required)'),
      ];
    //phones processing
      $form['mailgo_process_phones'] = [
          '#type' => 'checkbox',
          '#title' => $this->t('Process phone numbers'),
          '#default_value' => !empty($this->settings['mailgo_process_phones'])  ? 1 : 0,
          '#description' => $this->t('Phone numbers will be performed as MailGo-links'),
      ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function process($text, $langcode) {
    /** @var MailGoManager $service */
    $service = \Drupal::service('mailgo');
    $config = $service->getConfig();
    $isDark = $config->get('mailgo.skin') === 'dark';
    $attachments = [
      'library' => $isDark ? 'mailgo/mailgo-dark' : 'mailgo/mailgo'
    ];
    $text = $service->stripMailto($text);
    if (!empty($this->settings['mailgo_process_emails'])) {
      $text = $service->processEmailsInText($text, $this->settings['mailgo_no_spam']);
    }
    if (!empty($this->settings['mailgo_process_phones'])) {
      $text = $service->processPhonesInText($text);
    }
    return (new FilterProcessResult($text))
      ->setAttachments($attachments);
  }

  /**
   * {@inheritdoc}
   */
  public function tips($long = FALSE) {
    if ($long) {
      return $this->t('<p>You can convert emails & phone numbers to MailGo links</p>');
    }
    else {
      return $this->t('You can convert emails & phone numbers to MailGo links');
    }
  }
}
